import tempfile
import platform
import subprocess
from sys import version_info
from setuptools import setup
from pathlib import Path
from pkgutil import iter_modules
from setuptools import setup, find_packages
# To be replaced by: from setuptools_scm import get_version
def get_version():
    return "1.5.0"


def _mmind_sdk_version():
    return "1.6.6"


def _mmind_python_version():
    scm_version = get_version()

    if "+" in scm_version:
        base_version, scm_metadata = scm_version.split("+", 1)
    else:
        base_version = scm_version
        scm_metadata = None

    base_version = "{}.{}".format(base_version, _mmind_sdk_version())

    if scm_metadata:
        version = "{}+{}".format(base_version, scm_metadata)
    else:
        version = base_version

    return version


def _python_version():
    return "{}.{}.{}".format(*version_info)


def _main():
    # This list is a duplicate of the build-system requirements in pyproject.toml.
    # The purpose of these checks is to help users with PIP<19 lacking support for
    # pyproject.toml
    # Keep the two lists in sync

    setup(
        name="MechEyeAPI",
        version=_mmind_python_version(),
        description="Mech-Mind Robotics 3D Camera API",
        long_description=Path("README.md").read_text(encoding="utf-8"),
        long_description_content_type="text/markdown",
        url="https://www.mech-mind.com",
        author="Mech-Mind Robotics",
        author_email="",
        license="BSD 3-Clause",
        packages=["MechEye", "_MechEye"],
        package_dir={"": "modules"},
        install_requires=["numpy"],
		include_package_data=True,
        cmake_args=[
            "-DMECHEYE_PYTHON_VERSION=" + _mmind_python_version(),
            "-DMECHEYE_SDK_VERSION=" + _mmind_sdk_version(),
            "-DPYTHON_INTERPRETER_VERSION=" + _python_version(),
        ],
        classifiers=[
            "License :: OSI Approved :: BSD License",
            "Programming Language :: Python :: 3",
            "Programming Language :: Python :: Implementation :: CPython",
            "Topic :: Scientific/Engineering",
        ],
	   
    )

if __name__ == "__main__":
    _main()
